@@ -4,14 +4,18 @@
 import logging
 import logging.config
 import os
+import sys
 
 from enosapi.request.EnOSRequest import EnOSRequest
 from enosapi.util.Sign import Sign
 from enosapi.util.const import Const
-import urllib2
 import json
 import time
-from poster.streaminghttp import register_openers
+import requests
+if sys.version_info[0] < 3:
+    import urllib2
+else:
+    import urllib.request as urllib2
 
 
 class EnOSDefaultClient:
@@ -44,50 +48,38 @@ class EnOSDefaultClient:
 
     def do_get(self, request):
         url = self.__get_base_url(request)
-
-        headers = {"content-type": request.get_content_type()}
-
         param_str = ''
-        if request.replace_params_and_headers():
-            param_str = request.get_replace_params_and_headers()
-        else:
-            params = request.get_params()
-            if params is not None:
-                assert isinstance(params, dict)
-                for key in params:
-                    if "orgId" == key or "requestTimestamp" == key:
-                        pass
-                    else:
-                        param_str += "&"
-                        param_str += key
-                        param_str += "="
-                        param_str += str(params[key])
+        params = request.get_params()
+        if params is not None:
+            assert isinstance(params, dict)
+            for key in params:
+                if "orgId" == key or "requestTimestamp" == key:
+                    pass
+                else:
+                    param_str += "&"
+                    param_str += key
+                    param_str += "="
+                    param_str += str(params[key])
 
         if len(param_str) > 0:
             url += param_str
 
         self.__logging.info("do get execute:%s", url)
-        req = urllib2.Request(url, headers=headers)
-
-        res_data = urllib2.urlopen(req, timeout=self.timeout)
-        res = res_data.read()
+        res = requests.get(url).content
         self.__logging.info("response :%s", res)
         return res
 
     def do_post(self, request):
-        register_openers()
         url = self.__get_base_url(request)
-        if request.replace_params_and_headers():
-            data, headers = request.get_replace_params_and_headers()
-        else:
-            data = json.dumps(request.get_params())
-            headers = {"content-type": request.get_content_type()}
-
-        req = urllib2.Request(url, data=data, headers=headers)
-
+        data = request.get_params() if not request.replace_params() else request.get_replace_params()
+        upload_file = getattr(request, 'upload_file') if hasattr(request, 'upload_file') else None
         self.__logging.info("do post execute:%s ", url)
-        res_data = urllib2.urlopen(req, timeout=self.timeout)
-        res = res_data.read()
+        if upload_file:
+            res = requests.post(url, data=data, files=request.upload_file).content
+        else:
+            headers = request.get_headers()
+            req = urllib2.Request(url, data=data.encode('utf8'), headers=headers)
+            res = urllib2.urlopen(req, timeout=self.timeout).read()
         self.__logging.info("response :%s", res)
         return res
 
