@@ -6,7 +6,6 @@
 
 from enosapi.request.EnOSRequest import EnOSRequest
 from enosapi.util.const import Const
-from poster.encode import multipart_encode
 
 
 class PostMeasurepointsEnOSRequest(EnOSRequest):
@@ -32,11 +31,3 @@ class PostMeasurepointsEnOSRequest(EnOSRequest):
 
     def get_params(self):
         return self.params
-
-    def replace_params_and_headers(self):
-        return True
-
-    def get_replace_params_and_headers(self):
-        encode = dict(self.get_params(), **self.upload_file)
-        data, headers = multipart_encode(encode)
-        return data, headers
